/* -*- pftp-c -*- */
#ifdef HAVE_CONFIG_H
# include "config.h"
#endif
#if HAVE_STDLIB_H
# include <stdlib.h>
#endif
#if HAVE_STDIO_H
# include <stdio.h>
#endif
#if HAVE_UNISTD_H
# include <unistd.h>
#endif
#if HAVE_STRING_H
# include <string.h>
#endif
#if HAVE_FNMATCH_H
# include <fnmatch.h>
#endif
#if HAVE_INTTYPES_H
# include <inttypes.h>
#endif
#if HAVE_TIME_H
# include <time.h>
#endif

#ifdef WITH_DMALLOC
# include <dmalloc.h>
#endif

#include "patternmatch.h"
#include <pftp_directory.h>

//returnerar 0 om ngon match och 1 om ingen match
int listfnmatch(char *str, char **p, size_t nr)
{
    size_t I = 0;
    while (I < nr) {
	if(!fnmatch(p[I], str,0))
	    return 0;
	I++;
    }
    return 1;
} 

void priolist(pftp_directory_t *dir, char **prio, size_t p)
{
    size_t i, j, nr = 0;
    pftp_file_t tmp;

    for (i = 0; i < p; i++) {
	j = nr;

	while (j < dir->length) {
	    if (!fnmatch(prio[i], dir->files[j].name, 0)) {
		if (j > nr) {
		    memcpy(&tmp, dir->files + nr, sizeof(pftp_file_t));
		    memmove(dir->files + nr, dir->files + j, 
			    sizeof(pftp_file_t));
		    memcpy(dir->files + j, &tmp, sizeof(pftp_file_t));
		}
		nr++;
	    }
	    j++;
	}
    }
}
